summaryrefslogtreecommitdiff
path: root/libgo/go/math/remainder.go
diff options
context:
space:
mode:
Diffstat (limited to 'libgo/go/math/remainder.go')
-rw-r--r--libgo/go/math/remainder.go4
1 files changed, 2 insertions, 2 deletions
diff --git a/libgo/go/math/remainder.go b/libgo/go/math/remainder.go
index be8724c7f3a..7fb8a12f9e6 100644
--- a/libgo/go/math/remainder.go
+++ b/libgo/go/math/remainder.go
@@ -24,7 +24,7 @@ package math
// precision arithmetic, where [x/y] is the (infinite bit)
// integer nearest x/y (in half way cases, choose the even one).
// Method :
// Based on fmod() returning x - [x/y]chopped * y exactly.
// Remainder returns the IEEE 754 floating-point remainder of x/y.
//
@@ -60,7 +60,7 @@ func Remainder(x, y float64) float64 {
return 0
}
if y <= HalfMax {
- x = Fmod(x, y+y) // now x < 2y
+ x = Mod(x, y+y) // now x < 2y
}
if y < Tiny {
if x+x > y {
@@ -24,7 +24,7 @@ package math
// integer nearest x/y (in half way cases, choose the even one).
// Method :
-// Based on fmod() returning x - [x/y]chopped * y exactly.
+// Based on Mod() returning x - [x/y]chopped * y exactly.
// Remainder returns the IEEE 754 floating-point remainder of x/y.
//